@@ -864,9 +864,6 @@ class Scatterer:
 
     def scatter_grid_indexes(self, grid, indexes):
 
-        print(grid)
-        print(grid.shape_1d)
-
         if not isinstance(grid, np.ndarray):
             raise exc.PlottingException(
                 "The grid passed into scatter_grid_indexes is not a ndarray and thus its"
@@ -1238,6 +1235,96 @@ class Liner:
             )
 
 
+class ParallelOverscanLiner(Liner):
+    def __init__(
+        self,
+        width=None,
+        style=None,
+        colors=None,
+        pointsize=None,
+        from_subplot_config=False,
+    ):
+
+        super(ParallelOverscanLiner, self).__init__(
+            width=width,
+            style=style,
+            colors=colors,
+            pointsize=pointsize,
+            section="parallel_overscan",
+            from_subplot_config=from_subplot_config,
+        )
+
+    @classmethod
+    def sub(cls, width=None, style=None, colors=None, pointsize=None):
+        return ParallelOverscanLiner(
+            width=width,
+            style=style,
+            colors=colors,
+            pointsize=pointsize,
+            from_subplot_config=True,
+        )
+
+
+class SerialPrescanLiner(Liner):
+    def __init__(
+        self,
+        width=None,
+        style=None,
+        colors=None,
+        pointsize=None,
+        from_subplot_config=False,
+    ):
+
+        super(SerialPrescanLiner, self).__init__(
+            width=width,
+            style=style,
+            colors=colors,
+            pointsize=pointsize,
+            section="serial_prescan",
+            from_subplot_config=from_subplot_config,
+        )
+
+    @classmethod
+    def sub(cls, width=None, style=None, colors=None, pointsize=None):
+        return SerialPrescanLiner(
+            width=width,
+            style=style,
+            colors=colors,
+            pointsize=pointsize,
+            from_subplot_config=True,
+        )
+
+
+class SerialOverscanLiner(Liner):
+    def __init__(
+        self,
+        width=None,
+        style=None,
+        colors=None,
+        pointsize=None,
+        from_subplot_config=False,
+    ):
+
+        super(SerialOverscanLiner, self).__init__(
+            width=width,
+            style=style,
+            colors=colors,
+            pointsize=pointsize,
+            section="serial_overscan",
+            from_subplot_config=from_subplot_config,
+        )
+
+    @classmethod
+    def sub(cls, width=None, style=None, colors=None, pointsize=None):
+        return SerialOverscanLiner(
+            width=width,
+            style=style,
+            colors=colors,
+            pointsize=pointsize,
+            from_subplot_config=True,
+        )
+
+
 class ArrayOverlayer:
     def __init__(self, alpha=None, section=None, from_subplot_config=False):
 
