@@ -9,7 +9,7 @@ class TestSettingsPixelization:
         settings = aa.SettingsPixelization(use_border=True)
         assert settings.use_border_tag == ""
         settings = aa.SettingsPixelization(use_border=False)
-        assert settings.use_border_tag == "__no_border"
+        assert settings.use_border_tag == "no_border"
 
     def test__stochastic_tag(self):
 
@@ -28,6 +28,11 @@ class TestSettingsPixelization:
         settings = settings.settings_with_is_stochastic_true()
         assert settings.is_stochastic == True
 
+    def test__tag(self):
+
+        settings = aa.SettingsPixelization(use_border=False, is_stochastic=True)
+        assert settings.tag == "pix[no_border__stochastic]"
+
 
 class TestRectangular:
     def test__pixelization_grid_returns_none_as_not_used(self, sub_grid_7x7):
